const Api = {
  // ******************** Server -> Client ********************
  ROOM_STATE: 'room_state',
  CALLED_HINT: 'called_hint',
  CALLED_SKIP: 'called_skip',
  CALLED_RESET: 'called_reset',
  SONG_SKIPPED: 'song_skipped',
  CORRECT_ANSWER: 'correct_answer',
  GUESSING_DONE: 'guessing_done',
  SONG_ENDED: 'song_ended',
  SONG_SKIPPED: 'song_skipped',
  HONORED: 'honored',
  CLIENT_JOINED: 'client_joined',
  CLIENT_LEFT: 'client_left',
  SHOW_HINT: 'show_hint',
  // A new song is ready and will start playing soon.
  NEXT_SONG_ANNOUNCE: 'next_song_announce',
  // Clearing the current audio buffer.
  CLEAR_HOST_CHUNKS: 'clear_host_chunks',
  HOST_DISCONNECTED: 'host_disconnected',

  // ******************** Client -> Server ********************
  SKIP: 'skip',
  HINT: 'hint',
  HONOR: 'honor',
  RESET_SCORE: 'reset_score',
  GROUPIFY: 'groupify',

  // ******************** Both directions ********************
  // Clients sends this to server when you say something in the chat.
  // Server also sends it further to other clients, to let them know what was
  // said.
  // It is not used for slash-commands! Those are processed and executed on
  // the client.
  SAY: 'say',
  // This could be client-initiated, or /groupify initiated.
  // In both cases all the other clients should be aware of it.
  CHANGE_GROUP: 'change_group',
  // These two are initiated by the client, but the server sends back the 
  // response in the message of a same type.
  CREATE_ROOM: 'create_room',
  CHECK_ROOM: 'check_room',
  ENTER_ROOM: 'enter_room'
};

// WARNING: These are duplicated in the extension codebase.
//
// In both server initiated and extension initiated messages, the receiver
// sends the response (if any) in the message of a same type.
const ExtensionApi = {
  // ******************** Extension initiated ********************
  INIT_EXTENSION: 'initExtension',
  STARTED_STREAMING: 'startedStreaming',
  SONG_HAS_ENDED: 'songHasEnded',

  // ******************** Server initiated ********************
  START_PLAYING: 'startPlaying',
  MOVE_TO_NEXT_SONG: 'moveToNextSong'
};

const RoomState = {
  DEAD: 'dead',
  AFTER: 'after',
  SUSPENSE: 'suspense',
  PLAYING: 'playing',
  PLAY_ON: 'playon'
};

if (typeof exports !== 'undefined') {
  exports.Api = Api;
  exports.ExtensionApi = ExtensionApi;
  exports.RoomState = RoomState;
}
